@@ -1,5 +1,5 @@
 #include <QtGui/QApplication>
-#include <Phonon>
+#include <phonon>
 #include "mainwindow.h"
 #include "symfoniemediaplayer.cpp"
 #include "symfonieplaylistitemfolder.h"
@@ -19,7 +19,5 @@ int main(int argc, char *argv[])
     MainWindow w(&a, player);
     w.show();
 
-    SymfonieMetaReader reader;
-    reader.start();
     return a.exec();
 }
