@@ -48,7 +48,9 @@ MainWindow::MainWindow(const QApplication *app, SymfonieMediaPlayer* player, QWi
         isResumePlayback(false),
         isMainToolbarVisible(false),
         isSeekSliderShown(true),
-        fileListWidgetItemFileToDelete(QString())
+        fileListWidgetItemIndexToDelete(-1),
+        forceUpdatePlayList(false),
+        isSubDirScanned(false)
 {
     this->setAttribute(Qt::WA_Maemo5StackedWindow);
     ui->setupUi(this);
@@ -58,16 +60,28 @@ MainWindow::MainWindow(const QApplication *app, SymfonieMediaPlayer* player, QWi
 
     this->ui->mainToolBar2->hide();
 
+    this->changeFileListWidgetFontSize(SymfonieDb::getInstance()->getSetting("playlist_font_size", 14).toInt());
+
+
 
     if(SymfonieDb::getInstance()->getSetting("is_seekSlider_visible", QVariant(0)).toInt() == 0){
         this->isSeekSliderShown = false;
         this->ui->sliderPanel->hide();
+
     }else{
         this->isSeekSliderShown = true;
         this->ui->sliderPanel->show();
     }
 
 
+    //disable scroll panning
+    QAbstractKineticScroller *scroller = this->ui->fileListWidget->property("kineticScroller")
+                                         .value<QAbstractKineticScroller *>();
+    if (scroller){
+        scroller->setOvershootPolicy(QAbstractKineticScroller::OvershootAlwaysOff);
+    }
+
+
     //set up menus
     orientationGroup = new QActionGroup(this);
     orientationGroup->setExclusive(true);
@@ -132,6 +146,7 @@ MainWindow::MainWindow(const QApplication *app, SymfonieMediaPlayer* player, QWi
 
     connect(this->ui->menuActionEqualizer, SIGNAL(triggered()), this, SLOT(showEqualizerWindowSlot()));
 
+    connect(this->ui->menuActionSupportSymfonie, SIGNAL(triggered()), this, SLOT(supportSymfonieSlot()));
 
 
     connect(this->ui->menuActionAbout, SIGNAL(triggered()), this, SLOT(showAboutWindowSlot()));
@@ -191,9 +206,9 @@ MainWindow::MainWindow(const QApplication *app, SymfonieMediaPlayer* player, QWi
                                                 tr("Switch Orientation"), ui->mainToolBar);
 
 
-    this->showInfoWindowAction  = new QAction(tr("Seek"), ui->mainToolBar);
-    this->showInfoWindowAction->setCheckable(true);
-    connect(showInfoWindowAction, SIGNAL(triggered()), this, SLOT(showInfoWindowSlot()));
+   // this->showInfoWindowAction  = new QAction(tr("Seek"), ui->mainToolBar);
+   // this->showInfoWindowAction->setCheckable(true);
+
 
 
     this->showToolBar2Action  = new QAction(QIcon::fromTheme("general_speaker"), tr("Show Volume Control"), ui->mainToolBar);
@@ -204,10 +219,27 @@ MainWindow::MainWindow(const QApplication *app, SymfonieMediaPlayer* player, QWi
     this->goHomeAction = new QAction(QIcon::fromTheme("general_device_root_folder"), tr("Go Home"), ui->mainToolBar);
     connect(goHomeAction, SIGNAL(triggered()), this, SLOT(goHomeSlot()));
 
+    this->shuffleAction = new QAction(QIcon::fromTheme("mediaplayer_default_shuffle"), tr("Shuffle"), ui->mainToolBar);
+    this->shuffleAction->setCheckable(true);
+    connect(this->shuffleAction, SIGNAL(toggled(bool)), this, SLOT(shuffleSlot(bool)));
+
+    this->repeatAction = new QAction(QIcon::fromTheme("imageviewer_crop"), tr("Repeat"), ui->mainToolBar);
+    this->repeatAction->setCheckable(true);
+    connect(this->repeatAction, SIGNAL(toggled(bool)), this, SLOT(repeatSlot(bool)));
 
 
+    this->scanDirAction = new QAction(tr("Sub"), ui->mainToolBar);
+    this->scanDirAction->setCheckable(true);
+    this->connect(this->scanDirAction, SIGNAL(toggled(bool)), this, SLOT(scanSubFolderPressedSlot(bool)));
+
+
+
+
+/*
     this->showSpeedDialogAction = new QAction(QIcon::fromTheme("general_clock"), tr("Go Home"), ui->mainToolBar);
     this->connect(showSpeedDialogAction, SIGNAL(triggered()), this, SLOT(showSpeedDialogSlot()));
+*/
+
 
 
     this->goToCurDir = new QAction(QIcon::fromTheme("imageviewer_rotate"), tr("Go to current directory"), ui->mainToolBar);
@@ -223,7 +255,7 @@ MainWindow::MainWindow(const QApplication *app, SymfonieMediaPlayer* player, QWi
     connect(this->player->getMediaObject(), SIGNAL(tick(qint64)), this, SLOT(playerTickSlot(qint64)));
 
 
-    connect(nextAction, SIGNAL(triggered()), this, SLOT(showInfoWindowSlot()));
+   // connect(nextAction, SIGNAL(triggered()), this, SLOT(showInfoWindowSlot()));
 
 
     // this->ui->volumePanel->layout()->addWidget(this->volumeSlider);
@@ -272,7 +304,7 @@ MainWindow::MainWindow(const QApplication *app, SymfonieMediaPlayer* player, QWi
 
     this->ui->fileListWidget->setContextMenuPolicy(Qt::CustomContextMenu);
 
-    // connect(this->ui->fileListWidget, SIGNAL(customContextMenuRequested(const QPoint &)), this, SLOT(fileListItemContextMenu(const QPoint &)));
+    connect(this->ui->fileListWidget, SIGNAL(customContextMenuRequested(const QPoint &)), this, SLOT(fileListItemContextMenu(const QPoint &)));
 
 
 
@@ -319,11 +351,18 @@ MainWindow::MainWindow(const QApplication *app, SymfonieMediaPlayer* player, QWi
 }
 
 void MainWindow::deleteFileSlot(){
-    qDebug() << "Trying to delete file: " <<this->fileListWidgetItemFileToDelete;
+    if(this->fileListWidgetItemIndexToDelete < 0){
+        qDebug() << "Nothing selected. this->fileListWidgetItemIndexToDelete" << this->fileListWidgetItemIndexToDelete;
+        return;
+    }
+    QString filePath = this->currentPlayList
+                       ->get(this->fileListWidgetItemIndexToDelete)
+                       ->getName();
+    qDebug() << "Trying to delete file: " << filePath;
 
     QMessageBox msgBox;
     // msgBox.setText(tr("File Deletion"));
-     msgBox.setInformativeText(tr("Are you sure you want to delete this file?\n") + this->fileListWidgetItemFileToDelete);
+     msgBox.setInformativeText(tr("Are you sure you want to delete this file?\n") + filePath);
      msgBox.setStandardButtons(QMessageBox::Yes | QMessageBox::No | QMessageBox::Cancel);
      msgBox.setDefaultButton(QMessageBox::No);
      int ret = msgBox.exec();
@@ -334,24 +373,51 @@ void MainWindow::deleteFileSlot(){
      }
 
 
-    QFileInfo info = QFileInfo(this->fileListWidgetItemFileToDelete);
+    QFileInfo info = QFileInfo(filePath);
     if(!info.exists() || !info.isFile()){
         qDebug() << "deleteFileSlot: not a filed, operation skipped.";
         return;
     }
 
-  //  this->getPlayer()->getMediaObject()->stop();
+    if(
+            QString::compare(this->getCurrentDiretory(), this->getPlayer()->getCurrentDirectory()) == 0 &&
+            this->fileListWidgetItemIndexToDelete == this->getPlayer()->getCurrentPlaybackIndex()){
+        this->getPlayer()->stop();
+        this->forceUpdatePlayList = true;
+    }
 
-    if(!QFile::remove(this->fileListWidgetItemFileToDelete)){
-        qDebug() << "deleteFileSlot: deletion failed: "<< this->fileListWidgetItemFileToDelete;
+
+
+    if(!QFile::remove(filePath)){
+        qDebug() << "deleteFileSlot: deletion failed: "<< filePath;
+        QMessageBox msgBox;
+        msgBox.setInformativeText(tr("Unable to delete selected file."));
+        msgBox.exec();
         return;
     }
 
+
     this->getPlayer()->scanDir(this->getCurrentDiretory());
 
 
 }
 
+
+
+
+void MainWindow::scanSubFolderPressedSlot(bool isChecked){
+  qDebug() << this->getPlayer()->getCurrentDirectory() << this->getCurrentDiretory();
+
+  this->getPlayer()->stop();
+
+  if(isChecked){
+      this->getPlayer()->scanDirRecursive(this->getCurrentDiretory());
+  }else{
+      this->getPlayer()->scanDir(this->getCurrentDiretory());
+  }
+
+}
+
 void MainWindow::fileListItemContextMenu(const QPoint &pos){
 
     QListWidgetItem *item = this->ui->fileListWidget->itemAt(pos);
@@ -361,18 +427,24 @@ void MainWindow::fileListItemContextMenu(const QPoint &pos){
         return;
     }
 
-    itemIndex = item->data(Qt::UserRole).toInt();
+      itemIndex = item->data(Qt::UserRole).toInt();
+
+    if(this->currentPlayList->get(itemIndex)->getItemType() != SymfoniePlayListItemFile::File){
+        return;
+    }
+
+
 
     SymfonieQMenu *menu = new SymfonieQMenu();
 
 
-    if(this->getPlayer()->getPlayList()->get(itemIndex)->getItemType() == SymfoniePlayListItemFile::File){
-        this->fileListWidgetItemFileToDelete = this->getPlayer()->getPlayList()->get(itemIndex)->getName();
-        menu->addAction(tr("Delete File"), this, SLOT(deleteFileSlot()));
-    }
+
+    this->fileListWidgetItemIndexToDelete = itemIndex;
+    menu->addAction(tr("Delete File"), this, SLOT(deleteFileSlot()));
+
     menu->exec(this->mapToGlobal(pos));
-   // delete menu;
-    this->fileListWidgetItemFileToDelete = QString();
+    // delete menu;
+    this->fileListWidgetItemIndexToDelete = -1;
 
 
 }
@@ -391,20 +463,26 @@ MainWindow::~MainWindow()
     delete prevAction;
     delete nextAction;
 
+    delete this->repeatAction;
+    delete this->shuffleAction;
+
     delete toggleFullScreenAction;
     delete switchOrientationAction;
-    delete showInfoWindowAction;
+    //delete showInfoWindowAction;
     delete showToolBar2Action;
 
-    delete showSpeedDialogAction;
+    //delete showSpeedDialogAction;
 
     delete goUpAction;
     delete goHomeAction;
     delete goToCurDir;
+
     if(this->timerWindow != NULL){
         delete this->timerWindow;
     }
-    delete this->player;
+
+
+
 
     delete this->equalizerWindow;
 
@@ -424,6 +502,9 @@ MainWindow::~MainWindow()
         delete this->speedDialog;
     }
 
+   // @todo find out why this cause segmentation error
+    //delete this->player;
+
 }
 
 void MainWindow::showSpeedDialogSlot(){
@@ -431,16 +512,16 @@ void MainWindow::showSpeedDialogSlot(){
         this->speedDialog = new SymfonieSpeedDialog(this);
         this->connect(
                 speedDialog,
-                SIGNAL(speedChangedSignal(float)),
+                SIGNAL(speedChangedSignal(double)),
                 this,
-                SLOT(showSpeedDialogSliderChangedSlot(float))
+                SLOT(showSpeedDialogSliderChangedSlot(double))
                 );
     }
 
     this->speedDialog->exec();
 }
 
-void MainWindow::showSpeedDialogSliderChangedSlot(float value){
+void MainWindow::showSpeedDialogSliderChangedSlot(double value){
     qDebug() << "Speed value from dialog: " << value;
     this->getPlayer()->setSpeed(value);
 }
@@ -457,11 +538,15 @@ void MainWindow::setupToolBarButtonsLandscape(){
     this->ui->mainToolBar->addAction(prevAction);
     this->ui->mainToolBar->addAction(playAction);
     this->ui->mainToolBar->addAction(nextAction);
+   // this->ui->mainToolBar->addAction(scanDirAction);
 
-    this->ui->mainToolBar->addAction(showInfoWindowAction);
+    //this->ui->mainToolBar->addAction(showInfoWindowAction);
     this->ui->mainToolBar->addAction(this->showToolBar2Action);
 
-    this->ui->mainToolBar->addAction(this->showSpeedDialogAction);
+    this->ui->mainToolBar->addAction(this->shuffleAction);
+    this->ui->mainToolBar->addAction(this->repeatAction);
+
+    //this->ui->mainToolBar->addAction(this->showSpeedDialogAction);
     //this->ui->mainToolBar->addAction(this->toggleFullScreenAction);
 
     this->ui->mainToolBar2->hide();
@@ -479,15 +564,18 @@ void MainWindow::setupToolBarButtonsPortrait(){
     this->ui->mainToolBar2->addAction(prevAction);
     this->ui->mainToolBar2->addAction(playAction);
     this->ui->mainToolBar2->addAction(nextAction);
+   // this->ui->mainToolBar2->addAction(scanDirAction);
 
-    this->ui->mainToolBar2->addAction(showInfoWindowAction);
+    //this->ui->mainToolBar2->addAction(showInfoWindowAction);
     this->ui->mainToolBar2->addAction(this->showToolBar2Action);
 
 
     this->ui->mainToolBar->addAction(this->goHomeAction);
     this->ui->mainToolBar->addAction(this->goUpAction);
     this->ui->mainToolBar->addAction(this->goToCurDir);
-    this->ui->mainToolBar->addAction(this->showSpeedDialogAction);
+    this->ui->mainToolBar->addAction(this->shuffleAction);
+    this->ui->mainToolBar->addAction(this->repeatAction);
+   // this->ui->mainToolBar->addAction(this->showSpeedDialogAction);
 
     // this->ui->mainToolBar->addAction(this->toggleFullScreenAction);
 
@@ -535,6 +623,32 @@ void MainWindow::setOrientationMode(int mode){
 }
 
 
+void MainWindow::shuffleSlot(bool isChecked){
+
+    if(isChecked){
+        qDebug() << "enabling shuffle";
+        this->getPlayer()->enableShuffle();
+
+    }else{
+        qDebug() << "disabling shuffle";
+        this->getPlayer()->disableShuffle();
+    }
+}
+
+void MainWindow::repeatSlot(bool isChecked){
+    if(isChecked){
+        qDebug() << "repeat enabled";
+        this->getPlayer()->enableRepeat();
+    }else{
+        qDebug() << "repeat disabled";
+        this->getPlayer()->disableRepeat();
+    }
+}
+
+void MainWindow::supportSymfonieSlot(){
+    QDesktopServices::openUrl(QUrl("http://thecodecentral.com/symfonie#dd", QUrl::TolerantMode));
+}
+
 void MainWindow::toggleFullScreenOn(){
     toggleFullScreen(true);
 }
@@ -569,7 +683,7 @@ void MainWindow::clearTimerSlot(){
 }
 
 void MainWindow::setMenuActionTimerText(int time){
-    //qDebug() << "--------------------------setMenuActionTimerText: "<< time;
+
     if(time == 0){
         this->ui->menuActionTimer->setText("Sleep Timer");
     }else{
@@ -629,10 +743,25 @@ void MainWindow::showVolumeDialogSlot(){
 
         this->volumeDialog->layout()->addWidget(this->volumeSlider);
 
-        /*
-        connect(this->volumeDialog, SIGNAL(finished(int)),
-                this, SLOT(volumeDialogClosedSlot(int)));
-                */
+
+
+        qDebug() << "showVolumeDialogSlot"<<this->isSeekSliderShown;
+
+        this->volumeDialog->getShowSeekbarButton()->setChecked(this->isSeekSliderShown);
+
+       this->connect(this->volumeDialog, SIGNAL(speedChangedSignal(double)),
+                this, SLOT(showSpeedDialogSliderChangedSlot(double)));
+
+
+
+       this->connect(
+               this->volumeDialog->getShowSeekbarButton(),
+               SIGNAL(toggled(bool)),
+               this,
+               SLOT(showInfoWindowSlot(bool))
+             );
+
+
     }
 
     this->volumeDialog->exec();
@@ -660,6 +789,13 @@ void MainWindow::setToolbarVisibility(bool isShow){
 void MainWindow::optionsChangedSlot(int){
     this->isMainToolbarVisible = this->optionsDialog->getOptionIsShowToolbar();
     this->setToolbarVisibility(this->isMainToolbarVisible);
+    this->getPlayer()->setIsContinuouslyPlay(this->optionsDialog->getIsContinuouslyPlay());
+    this->changeFileListWidgetFontSize(this->optionsDialog->getPlayListFontSizeSbValue());
+
+}
+
+void MainWindow::changeFileListWidgetFontSize(int size){
+    this->ui->fileListWidget->setStyleSheet("font-size: " + QVariant(size).toString() + "px;");
 }
 
 
@@ -689,7 +825,6 @@ void MainWindow::goUpSlot(){
 
     QDir homeDir = QDir(QDir::homePath() + "/MyDocs");
     QDir mediaDir = QDir("/media");
-    qDebug() << "sdflskjadf=-===========: "<< homeDir.canonicalPath() << this->getCurrentDiretory();
 
 
     if(this->getCurrentDiretory().length() == 0 ||
@@ -718,6 +853,7 @@ bool MainWindow::saveLastDir(){
 
 
 void MainWindow::saveState(){
+
     this->saveLastDir();
     // qDebug() << "curent time: "<<this->getPlayer()->getMediaObject()->currentTime();
 
@@ -730,6 +866,9 @@ void MainWindow::saveState(){
     if(this->optionsDialog != NULL){
         SymfonieDb::getInstance()->saveSetting("is_show_main_toolbar", QVariant(this->optionsDialog->getOptionIsShowToolbar() ? 1:0));
         SymfonieDb::getInstance()->saveSetting("is_auto_resume_playback", QVariant(this->optionsDialog->getOptionIsAutoResumePlayback() ? 1:0));
+        SymfonieDb::getInstance()->saveSetting("is_continuously_play", QVariant(this->optionsDialog->getIsContinuouslyPlay() ? 1:0));
+        SymfonieDb::getInstance()->saveSetting("playlist_font_size", QVariant(this->optionsDialog->getPlayListFontSizeSbValue()));
+
     }
     SymfonieDb::getInstance()->saveSetting("is_show_volume_slider", QVariant(this->ui->volumePanel->isVisible() ? 1:0));
 }
@@ -839,22 +978,28 @@ void MainWindow::goHomeSlot(){
 }
 
 
-void MainWindow::showInfoWindowSlot(){
+void MainWindow::showInfoWindowSlot(bool isChecked){
+    qDebug() << "showInfoWindowSlot" << isChecked;
     if(this->ui->sliderPanel->isVisible()){
         this->ui->sliderPanel->hide();
-        this->showInfoWindowAction->setChecked(false);
+       // this->showInfoWindowAction->setChecked(false);
+        //this->volumeDialog->getShowSeekbarButton()->setChecked(false);
         this->isSeekSliderShown = false;
     }else{
         this->ui->sliderPanel->show();
-        this->showInfoWindowAction->setChecked(true);
+       // this->showInfoWindowAction->setChecked(true);
+       //this->volumeDialog->getShowSeekbarButton()->setChecked(true);
         this->isSeekSliderShown = true;
     }
 
+    this->volumeDialog->hide();
     this->setActionToggleState();
 }
 
 void MainWindow::setActionToggleState(){
-    this->showInfoWindowAction->setChecked(this->ui->subToolBar->isVisible());
+    //this->showInfoWindowAction->setChecked(this->ui->subToolBar->isVisible());
+
+    //this->volumeDialog->getShowSeekbarButton()->setChecked(this->ui->subToolBar->isVisible());
     this->showToolBar2Action->setChecked(this->ui->volumePanel->isVisible());
 }
 
@@ -949,7 +1094,7 @@ void MainWindow::insertItem(SymfoniePlayList* playList){
 
 
         if(item->getItemType() == SymfoniePlayListItem::File){
-            qDebug() << currentPlaybackIndex << this->getCurrentDiretory() << this->getPlayer()->getCurrentDirectory();
+           // qDebug() << currentPlaybackIndex << this->getCurrentDiretory() << this->getPlayer()->getCurrentDirectory();
             if(currentPlaybackIndex != -1 && QString::compare(this->getCurrentDiretory(), this->getPlayer()->getCurrentDirectory()) == 0){
                 if(QString::compare(item->getName(), currentPlaybackFile) == 0){
                     newItem->setSelected(true);
@@ -961,6 +1106,11 @@ void MainWindow::insertItem(SymfoniePlayList* playList){
 
         counter++;
     }
+
+    if(this->ui->fileListWidget->selectedItems().size() > 0){
+        this->ui->fileListWidget->scrollToItem(this->ui->fileListWidget->selectedItems().value(0), QAbstractItemView::EnsureVisible);
+    }
+
 }
 
 void MainWindow::changeEvent(QEvent *e)
@@ -978,6 +1128,8 @@ void MainWindow::changeEvent(QEvent *e)
 
 void MainWindow::itemActivatedSlot(QModelIndex index)
 {
+    this->ui->fileListWidget->setCurrentIndex(index);
+
     int row = index.row();
     SymfoniePlayList *playList = this->currentPlayList;
     SymfoniePlayListItem *item = playList->get(row);
@@ -987,25 +1139,27 @@ void MainWindow::itemActivatedSlot(QModelIndex index)
     }
 
     QString path = item->getName();
-    // qDebug() << "item index: " << index << " item at: " << path << item->getItemTypeName() << " curdir:" << this->getCurrentDiretory();
 
     if(item->getItemType() == SymfoniePlayListItem::Directory){
         this->setCurrentDirectory(path);
         this->getPlayer()->scanDir(this->getCurrentDiretory());
     }else if(item->getItemType() == SymfoniePlayListItem::DotDot){
-        //this->setCurrentDirectory(path);
         this->goUpSlot();
     }else if(item->getItemType() == SymfoniePlayListItem::File){
+
+
+        bool isCurrentDirChanged;
         if(QString::compare(this->getCurrentDiretory(), this->getPlayer()->getCurrentDirectory()) == 0){
-
+            isCurrentDirChanged = false;
         }else{
-            //this->getPlayer()->scanDir(this->getCurrentDiretory(), true);
-
             this->getPlayer()->setPlayList(this->currentPlayList);
-
+            isCurrentDirChanged = true;
         }
 
-        if(row == this->getPlayer()->getCurrentPlaybackIndex() && (
+
+        if(row == this->getPlayer()->getCurrentPlaybackIndex() &&
+           !isCurrentDirChanged &&
+            (
                 this->player->getMediaObject()->state() == Phonon::PlayingState ||
                 this->player->getMediaObject()->state() == Phonon::PausedState
                 )){
@@ -1036,12 +1190,11 @@ void MainWindow::playSlot(){
 }
 
 void MainWindow::playNextSlot(){
-    qDebug() << "next";
     this->player->playNext();
-
-
 }
 
+
+
 void MainWindow::playPrevSlot(){
     qDebug() << "prev";
     this->player->playPrevious();
@@ -1064,9 +1217,9 @@ void MainWindow::mediaStateChangedSlot(Phonon::State newState, Phonon::State){
         // playAction->setEnabled(false);
         playAction->setIcon(style()->standardIcon(QStyle::SP_MediaPause));
         //pauseAction->setEnabled(true);
-        stopAction->setEnabled(true);
+       // stopAction->setEnabled(true);
 
-        qDebug() << "Current playback index: " << this->player->getCurrentPlaybackIndex() ;
+       // qDebug() << "Current playback index: " << this->player->getCurrentPlaybackIndex() ;
 
         if(QString::compare(this->getCurrentDiretory(), this->getPlayer()->getCurrentDirectory()) == 0){
             this->ui->fileListWidget->setCurrentItem( this->ui->fileListWidget->item(
@@ -1077,7 +1230,7 @@ void MainWindow::mediaStateChangedSlot(Phonon::State newState, Phonon::State){
 
         break;
        case Phonon::StoppedState:
-        stopAction->setEnabled(false);
+        //stopAction->setEnabled(false);
         playAction->setEnabled(true);
         playAction->setIcon(style()->standardIcon(QStyle::SP_MediaPlay));
         //pauseAction->setEnabled(false);
@@ -1085,12 +1238,12 @@ void MainWindow::mediaStateChangedSlot(Phonon::State newState, Phonon::State){
         break;
        case Phonon::PausedState:
         //pauseAction->setEnabled(false);
-        stopAction->setEnabled(true);
+       // stopAction->setEnabled(true);
         //playAction->setEnabled(true);
         playAction->setIcon(style()->standardIcon(QStyle::SP_MediaPlay));
         break;
        case Phonon::BufferingState:
-        qDebug() << "buffering";
+        //qDebug() << "buffering";
         break;
        default:
         ;
@@ -1115,8 +1268,11 @@ void MainWindow::playerScanDirCompletedSlot(SymfoniePlayList* playList, QString
     this->setCurrentDirectory(playList->getCurrentDirectory());
     this->insertItem(playList);
 
-
-
+    if(this->forceUpdatePlayList){
+        this->getPlayer()->stop();
+        this->getPlayer()->setPlayList(playList);
+        this->forceUpdatePlayList = false;
+    }
 
 
     if(this->isResumePlayback == true){
