@@ -73,7 +73,8 @@ private:
     QAction *prevAction;
     QAction *nextAction;
     QAction *switchOrientationAction;
-    QAction *showInfoWindowAction;
+    //QAction *showInfoWindowAction;
+    QAction *scanDirAction;
     QAction *showToolBar2Action;
     QAction *goUpAction;
     QAction *goHomeAction;
@@ -81,6 +82,9 @@ private:
     QAction *toggleFullScreenAction;
     QAction *showSpeedDialogAction;
 
+    QAction *shuffleAction;
+    QAction *repeatAction;
+
     QActionGroup *orientationGroup;
     QAction *orientationLandscape;
     QAction *orientationPortrait;
@@ -103,6 +107,7 @@ private:
 
     void setMenuActionTimerText(int time);
 
+
    void setupToolBarButtonsLandscape();
    void setupToolBarButtonsPortrait();
    void setOrientationMode(int mode);
@@ -112,11 +117,14 @@ private:
 
    bool isMainToolbarVisible;
    void setToolbarVisibility(bool isShow);
-   QString fileListWidgetItemFileToDelete;
+   int fileListWidgetItemIndexToDelete;
 
+   bool forceUpdatePlayList;
+
+   bool isSubDirScanned;
 
 public Q_SLOTS:
-      void showSpeedDialogSliderChangedSlot(float);
+      void showSpeedDialogSliderChangedSlot(double);
 
 private Q_SLOTS:
     void itemActivatedSlot(QModelIndex);
@@ -128,7 +136,7 @@ private Q_SLOTS:
     void playerDirectoryChangedSlot(QString);
     void playerScanDirCompletedSlot(SymfoniePlayList*, QString);
     void switchOrientationSlot();
-    void showInfoWindowSlot();
+    void showInfoWindowSlot(bool);
     void showToolBar2Slot();
     void goHomeSlot();
     void goUpSlot();
@@ -158,6 +166,15 @@ private Q_SLOTS:
     void fileListItemContextMenu(const QPoint &pos);
     void deleteFileSlot();
 
+    void changeFileListWidgetFontSize(int size);
+
+     void supportSymfonieSlot();
+
+     void shuffleSlot(bool);
+     void repeatSlot(bool);
+
+     void scanSubFolderPressedSlot(bool);
+
 
 
 };
