@@ -2,7 +2,7 @@
 #define SYMFONIEEQUALIZERWINDOW_H
 
 #include <QMainWindow>
-#include <Phonon>
+#include <phonon>
 
 class QStringList;
 class SymfonieQSlider;
@@ -14,17 +14,28 @@ namespace Ui {
 class SymfonieEqualizerWindow : public QMainWindow {
     Q_OBJECT
 public:
-    SymfonieEqualizerWindow(Phonon::Effect *effect, QWidget *parent = 0);
+    SymfonieEqualizerWindow(QWidget *parent = 0);
     ~SymfonieEqualizerWindow();
     void saveBandValue(int band, int value);
     int getBandValue(int band);
     void saveState();
 
+    bool getIsEnabled();
+    void setEqualizerEffect(Phonon::Effect *effect);
+    void syncSlidersValues();
+
+
+Q_SIGNALS:
+    void enabledStateChanged(bool);
+
+
 public Q_SLOTS:
     void slideValueChangedSlot(int index, int value);
+    void setWindowEnabled(bool);
 
 protected:
     void changeEvent(QEvent *e);
+    void showEvent ( QShowEvent * event );
 
 private:
     Ui::SymfonieEqualizerWindow *ui;
@@ -32,8 +43,10 @@ private:
     static QString bandNames[];
    QList<SymfonieQSlider*> *sliderList;
 
-   static const int EQ_BAR_MIN = 1; //0
-   static const int EQ_BAR_MAX = 9; //10
+   static const int EQ_BAR_MIN = 0; //0
+   static const int EQ_BAR_MAX = 10; //10
+
+   bool isEnabled;
 };
 
 #endif // SYMFONIEEQUALIZERWINDOW_H
