@@ -1,28 +1,71 @@
 #include <QDebug>
 #include <QStringList>
+#include <QCheckBox>
 #include "symfoniefiletypesdialog.h"
 #include "ui_symfoniefiletypesdialog.h"
 #include "symfoniedb.h"
 
+
+
 SymfonieFileTypesDialog::SymfonieFileTypesDialog(QWidget *parent) :
         QDialog(parent),
         ui(new Ui::SymfonieFileTypesDialog)
 {
+
+
+    this->fileTypeList
+            << "*.mp3"
+            << "*.wma"
+            << "*.m4a"
+            << "*.mp4"
+            << "*.ogg"
+            << "*.wav"
+            << "*.flac"
+            << "*.acc"
+            << "*.m4p"
+            << "*.ape"
+            << "*.3pg"
+            << "*.ra"
+            << "*.gsm"
+            << "*.dct"
+            << "*.vox"
+            << "*.mmf"
+            << "*.au"
+            << "*.mpc"
+            << "*.aiff"
+            << "*.raw"
+            << "*.dss"
+            << "*.iklax"
+            << "*.dvf"
+            << "*.ivs"
+            << "*.mxp4"
+            << "*.amr"
+            << "*.awb"
+            ;
+
+
     ui->setupUi(this);
     this->setWindowTitle(tr("File Types"));
 
+
+    for(int i=0; i<this->fileTypeList.size(); i++){
+        QCheckBox* cb = new QCheckBox(this->fileTypeList.at(i));
+        this->fileTypeCbList.append(cb);
+        this->ui->cbLayout->addWidget(cb);
+    }
+
+
+
    this->updateCheckedFileTypes();
 
     connect(this, SIGNAL(finished(int)), this, SLOT(finishedSlot(int)));
 }
 
-SymfonieFileTypesDialog::~SymfonieFileTypesDialog()
-{
+SymfonieFileTypesDialog::~SymfonieFileTypesDialog(){
     delete ui;
 }
 
-void SymfonieFileTypesDialog::changeEvent(QEvent *e)
-{
+void SymfonieFileTypesDialog::changeEvent(QEvent *e){
     QDialog::changeEvent(e);
     switch (e->type()) {
     case QEvent::LanguageChange:
@@ -37,48 +80,27 @@ void SymfonieFileTypesDialog::changeEvent(QEvent *e)
 void SymfonieFileTypesDialog::updateCheckedFileTypes(){
     QStringList typeList = SymfonieFileTypesDialog::getSavedFilterList();
     for(int i=0; i < typeList.size(); i++){
-        if(QString::compare(typeList.at(i), "*.mp3") == 0){
-            this->ui->cbTypeMp3->setChecked(true);
-        }else if(QString::compare(typeList.at(i), "*.mp4") == 0){
-            this->ui->cbTypeMp4->setChecked(true);
-        }else if(QString::compare(typeList.at(i), "*.ogg") == 0){
-            this->ui->cbTypeOgg->setChecked(true);
-        }else if(QString::compare(typeList.at(i), "*.m4a") == 0){
-            this->ui->cbTypeM4a->setChecked(true);
-        }else if(QString::compare(typeList.at(i), "*.wav") == 0){
-            this->ui->cbTypeWav->setChecked(true);
-        }else if(QString::compare(typeList.at(i), "*.wma") == 0){
-            this->ui->cbTypeWma->setChecked(true);
+        for(int cbIndex=0; cbIndex<this->fileTypeList.size(); cbIndex++){
+            QCheckBox* cb = this->fileTypeCbList.at(cbIndex);
+            if(QString::compare(typeList.at(i), cb->text()) == 0){
+                cb->setChecked(true);
+
+            }
         }
+
     }
 }
 
 void SymfonieFileTypesDialog::finishedSlot(int){
     QString buff;
-    if(this->ui->cbTypeMp3->isChecked()){
-        buff += "*.mp3|";
-    }
 
-    if(this->ui->cbTypeM4a->isChecked()){
-        buff += "*.m4a|";
-    }
+     for(int cbIndex=0; cbIndex<this->fileTypeList.size(); cbIndex++){
+         if(this->fileTypeCbList.at(cbIndex)->isChecked()){
+             buff +=  this->fileTypeCbList.at(cbIndex)->text() + "|";
 
-    if(this->ui->cbTypeMp4->isChecked()){
-        buff += "*.mp4|";
-    }
-
-    if(this->ui->cbTypeOgg->isChecked()){
-        buff += "*.ogg|";
-    }
-
-    if(this->ui->cbTypeWav->isChecked()){
-        buff += "*.wav|";
-    }
-
-    if(this->ui->cbTypeWma->isChecked()){
-        buff += "*.wma|";
-    }
+         }
 
+     }
 
     SymfonieDb::getInstance()->saveSetting("file_filter", QVariant(buff));
 
@@ -104,7 +126,7 @@ QStringList SymfonieFileTypesDialog::serializePattern(QString str){
 QStringList SymfonieFileTypesDialog::getSavedFilterList(){
     QString pattern = SymfonieDb::getInstance()->getSetting("file_filter", QVariant()).toString();
     if(pattern.length() == 0){
-        pattern = "*.mp3|*.m4a|*.mp4|*.wav|*.ogg|*.wma";
+        pattern = "*.mp3|*.m4a|*.mp4|*.wav|*.ogg|*.wma|*.flac";
     }
 
     return SymfonieFileTypesDialog::serializePattern(pattern);
