@@ -4,6 +4,7 @@
 #include <QDialog>
 
 class QStringList;
+class QCheckBox;
 
 namespace Ui {
     class SymfonieFileTypesDialog;
@@ -30,6 +31,8 @@ private Q_SLOTS:
 
 private:
     Ui::SymfonieFileTypesDialog *ui;
+    QStringList fileTypeList;
+    QList<QCheckBox*> fileTypeCbList;
 };
 
 #endif // SYMFONIEFILETYPESDIALOG_H
