@@ -59,18 +59,27 @@ public:
     void playNext();
     void pause();
     void enqueue(int index);
+    void stop();
 
     void doTimer(int time);
     void stopTimer();
     int getTimerRemain();
     void setFileFilter(QStringList filterList);
 
-
-
     void startGraduateVolumeResuming(qreal value);
 
+    void setIsContinuouslyPlay(bool flag);
+    bool getIsContinuouslyPlay();
 
+    void enableShuffle();
+    void disableShuffle();
+    bool getIsShuffleEnabled();
 
+    void enableRepeat();
+    void disableRepeat();
+    bool getIsRepeatEnabled();
+
+    SymfoniePlayList* scanDirRecursive(QString path);
 
 
 Q_SIGNALS:
@@ -139,8 +148,15 @@ private:
     Phonon::Effect* getEffectDescriptionByName(QString effectName);
 
 
+    bool isContinuouslyPlay;
 
 
+    void scanDirRecursiveBase(SymfoniePlayList *playList, QString path);
+    QStringList getDirectoryListByPath(QString path);
+    QStringList getFileListByPath(QString path);
+    void doScanDirCompleted(SymfoniePlayList *playList, QString path);
+    void addInitialDir(SymfoniePlayList *playList, QString path);
+
 
 
 };
