@@ -3,6 +3,7 @@
 
 #include <QObject>
 #include <QDebug>
+#include <QHash>
 #include <QFileSystemModel>
 #include "symfonieplaylistitem.h"
 #include "symfonieplaylistitemfile.h"
@@ -35,11 +36,31 @@ public:
     SymfoniePlayListItem *get(int itemIndex);
     void clear();
 
+    bool isIndexLast(int indexToTest);
+
+    void enableShuffle();
+    void disableShuffle();
+    bool getIsShuffleEnabled();
+
+    void enableRepeat();
+    void disableRepeat();
+    bool getIsRepeatEnabled();
+
 private:
     QString curDir;
     QList<SymfoniePlayListItem*> *itemList;
     QList<QVariant> *fileIndexList;
+    QList<QVariant> *fileIndexListBackup; //when shuffle is enabled, used for backup
     int firstFileIndex; //-1 means no file in current directory
+
+    bool isShuffleEnabled;
+
+    bool isRepeatEnabled;
+
+   void shuffleList(QList<QVariant> *  list);
+
+
+
 };
 
 #endif // SYMFONIEPLAYLIST_H
