@@ -1,7 +1,7 @@
 #include "symfonieqmenu.h"
 
 SymfonieQMenu::SymfonieQMenu():
-        deleteFilePath(NULL)
+        deleteFilePath(QString())
 {
 }
 
